from setuptools import setup

setup(name='wicomm',
      version='0.1',
      description='Python package containing a wireless communication API.',
      url='http://hardworkin-man.com:8080/scm/git/wicomm',
      author='Mike Moore',
      author_email='mickety.mike@gmail.com',
      license='MIT',
      packages=['wicomm'],
      zip_safe=False)